@@ -19,7 +19,7 @@ use Time::HiRes;
 
 use Catalyst::Engine::HTTP::Restarter::Watcher;
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 # Enable for helpful debugging information
 sub DEBUG () { $ENV{CATALYST_POE_DEBUG} || 0 }
@@ -36,10 +36,6 @@ if ( BENCH ) {
     require Benchmark::Stopwatch;
 }
 
-$SIG{__WARN__} = sub {
-    warn '[' . sprintf( "%.4f", Time::HiRes::time() ) . '] ' . shift;
-};
-
 sub run { 
     my ( $self, $class, @args ) = @_;
     
@@ -60,6 +56,8 @@ sub spawn {
         $host = gethostbyaddr( $addr, AF_INET ) || inet_ntoa($addr);
     }
     
+    $self->{alias}  = delete $options->{alias} || 'catalyst-poe';
+    
     $self->{config} = {
         appclass   => $class,
         addr       => $addr,
@@ -78,6 +76,7 @@ sub spawn {
                    shutdown
                    child_shutdown
                    dump_state
+                   status
                    
                    prefork
                    sig_chld
@@ -115,7 +114,7 @@ sub spawn {
 sub _start {
     my ( $kernel, $self ) = @_[ KERNEL, OBJECT ];
     
-    $kernel->alias_set( 'catalyst-poe' );
+    $kernel->alias_set( $self->{alias} );
 
     # take a copy of %ENV
     $self->{global_env} = \%ENV;
@@ -140,8 +139,12 @@ sub _start {
     # dump our state if we get a SIGUSR1
     $kernel->sig( USR1 => 'dump_state' );
 
-    # shutdown on INT
-    $kernel->sig( INT => 'shutdown' );
+    # shutdown on INT and TERM
+    $kernel->sig( INT  => 'shutdown' );
+    $kernel->sig( TERM => 'shutdown' );
+    
+    # restart on HUP
+    $kernel->sig( HUP => 'restart' );
     
     # Pre-fork if requested
     $self->{config}->{options}->{max_proc} ||= MAX_PROC;
@@ -159,6 +162,8 @@ sub _start {
     my $url = 'http://' . $self->{config}->{host};
     $url .= ':' . $self->{config}->{port}
         unless $self->{config}->{port} == 80;
+    
+    $self->{url} = $url;
 
     print "You can connect to your server at $url\n";
 }
@@ -168,7 +173,7 @@ sub _stop { }
 sub shutdown {
     my ( $kernel, $self ) = @_[ KERNEL, OBJECT ];
     
-    DEBUG && warn "Shutting down...\n";
+    DEBUG && warn "Catalyst POE engine shutting down...\n";
     
     if ( my @children = keys %{ $self->{config}->{children} } ) {
         DEBUG && warn "Signaling all children to stop...\n";
@@ -178,7 +183,7 @@ sub shutdown {
     delete $self->{listener};
     delete $self->{clients};
     
-    $kernel->alias_remove( 'catalyst-poe' );
+    $kernel->alias_remove( $self->{alias} );
     
     return 1;
 }
@@ -198,6 +203,18 @@ sub dump_state {
     warn "Active clients: $clients\n";
 }
 
+sub status {
+    my ( $kernel, $self ) = @_[ KERNEL, OBJECT ];
+    
+    # XXX: Include more status stuff here
+    my $status = {
+        url            => $self->{url},
+        active_clients => scalar keys %{ $self->{clients} },
+    };
+    
+    return $status;
+}
+
 sub prefork {
     my ( $kernel, $self ) = @_[ KERNEL, OBJECT ];
     
@@ -896,7 +913,7 @@ __END__
 
 =head1 NAME
 
-Catalyst::Engine::HTTP::POE - Single-threaded multi-tasking Catalyst engine
+Catalyst::Engine::HTTP::POE - Single-threaded multi-tasking Catalyst engine (deprecated in favor of HTTP::Prefork)
 
 =head1 SYNOPIS
 
@@ -905,6 +922,10 @@ Catalyst::Engine::HTTP::POE - Single-threaded multi-tasking Catalyst engine
     # Prefork 5 children
     CATALYST_POE_MAX_PROC=6 CATALYST_ENGINE='HTTP::POE' script/yourapp_server.pl
 
+=head1 DEPRECATED
+
+This engine has been deprecated.  Please consider using L<Catalyst::Engine::HTTP::Prefork> instead.
+
 =head1 DESCRIPTION
 
 This engine allows Catalyst to process multiple requests in parallel within a
